import React, { useMemo } from "react";
import { makeStyles } from "@material-ui/styles";
import { Paper, Divider } from "@material-ui/core";

import { MenuSolverControls } from "./MenuSolverControls";
import { MenuMetrics } from "./MenuMetrics";
import { MemoryUsage } from "./MemoryUsage";
import { useThemeContext } from "../context";
const useStyles = makeStyles(theme => ({
  wrapper: {
    overflowY: "auto",
    flex: "0 0 400px",
    padding: theme.spacing(2),
    display: "flex",
    flexDirection: "column",
    flexWrap: "nowrap",
    alginItems: "flex-start",
    zIndex: 100
  },
  [theme.breakpoints.down("sm")]: {
    width: "100%"
  }
}));

export const Menu = ({
  onStart,
  onPause,
  onUnPause,

  onStop,

}) => {
  const classes = useStyles();
  const { muiTheme, colorMode } = useThemeContext();
  const backgroundStyle = useMemo(() =>
    colorMode === "dark" ? "#101010" : "#ffffff",
    [colorMode]
  );

  return (
    <Paper classes={{ root: classes.wrapper }} style={{
      position: "fixed",
      width: "370px",
      height: "625px",
      top: "80px",
      left: "20px",
      color: "white",
      padding: "15px",
      borderRadius: "8px",
      boxShadow: "2px 2px 10px rgba(0, 0, 0, 0.3)",
      backgroundColor: backgroundStyle,
    }}>
      <MenuMetrics />
      <Divider />
      <MenuSolverControls
        onStart={onStart}
        onPause={onPause}
        onUnPause={onUnPause}
        onStop={onStop}
      />
      <Divider />
      <MemoryUsage />
    </Paper>
  );
};
