import React from "react";
import {
    Navbar
} from "../components";


const AboutPage = () => {
    const containerStyle = {
        maxWidth: '900px',
        margin: '80px auto 20px',
        padding: '0 20px',
        fontFamily: 'Inter, sans-serif',
    };

    return (
        <>
            <Navbar />
            <div style={containerStyle}>
                <h1>About the Traveling Salesman Problem (TSP)</h1>
                <h2>What is the Traveling Salesman Problem?</h2>
                <p>The Traveling Salesman Problem (TSP) is a classic optimization problem in computer science and operations research. It asks:</p>
                <p><em>"Given a list of cities and the distances between them, what is the shortest possible route that visits each city exactly once and returns to the starting point?"</em></p>
                <p>TSP has applications in logistics, manufacturing, and route planning. However, solving it efficiently becomes difficult as the number of cities increases.</p>

                <h2>Solving TSP with Blind Search</h2>
                <p>Blind search methods explore solutions without using problem-specific knowledge:</p>
                <ul>
                    <li><strong>Brute Force:</strong> Generates all routes and picks the shortest. It guarantees an optimal solution but has a factorial time complexity.</li>
                    <li><strong>Breadth-First Search (BFS):</strong> Explores routes level by level but grows exponentially in complexity.</li>
                    <li><strong>Depth-First Search (DFS):</strong> Traverses full paths before backtracking but may not be optimal.</li>
                </ul>
                <p>Blind search methods are inefficient for large-scale TSP instances.</p>

                <h2>Solving TSP with Heuristic Search</h2>
                <p>Heuristic search methods use problem-specific knowledge to find solutions efficiently:</p>
                <ul>
                    <li><strong>Greedy Algorithm:</strong> Chooses the nearest unvisited city but does not guarantee the best solution.</li>
                    <li><strong>A* Search:</strong> Uses cost estimation to optimize the search.</li>
                    <li><strong>Genetic Algorithms:</strong> Uses evolution-based optimization.</li>
                    <li><strong>Simulated Annealing:</strong> Uses randomization to escape local optima.</li>
                    <li><strong>Ant Colony Optimization:</strong> Mimics how ants find paths efficiently.</li>
                </ul>
                <p>These methods balance accuracy and computational efficiency, making them suitable for real-world applications.</p>

                <h2>Conclusion</h2>
                <p>The Traveling Salesman Problem is a fundamental challenge in optimization and AI. While blind search guarantees the optimal route, its cost is too high for large problems. Heuristic search algorithms provide practical alternatives that yield near-optimal solutions efficiently.</p>
                <h4>Created by</h4>
                <ul>
                    <li>64010823 วีรภัทร อินอุดม</li>
                    <li>64010543 พงศ์ภีระ วงศประสิทธิพร</li>
                    <li>64011106 ณรงค์พล กิจรังสรรค์</li>
                    <li>64011160 นนทัช มุกลีมาศ</li>
                </ul>
            </div>
        </>
    );
};

export default AboutPage;
